

function ___$insertStyle(css) {
    if (!css || typeof window === 'undefined') {
        return;
    }
    const style = document.createElement('style');
    style.setAttribute('type', 'text/css');
    style.innerHTML = css;
    document.head.appendChild(style);
    return css;
}

Object.defineProperty(exports, '__esModule', { value: true });

var utils = require('./utils-093c7142.js');
var index$1 = require('./index-3ade7882.js');
var index = require('./index-9411f9b2.js');

var ignoreStatuses = ['OK', 'NO_ROWS'];
var crudAfterMiddleware = (function (store) {
  return function (next) {
    return function (action) {
      if (/.*_FAILURE$/gi.test(action.type) && action.meta.status !== 401) {
        next({
          type: 'ADD_NOTIFICATION',
          notification: {
            id: parseInt(Math.random().toString().split('.')[1], 10),
            duration: 7000,
            message: 'Something went wrong. Try again later.',
            type: 'NOTIFICATION_TYPE_ERROR',
            canDismiss: true
          }
        });
        return Promise.reject(next(action));
      }
      if (/.*_SUCCESS$/gi.test(action.type)) {
        var cloneAction = index.lodash_clonedeep(action);
        // validate response crud data
        if (!cloneAction.payload.status || !cloneAction.payload.status.length) {
          cloneAction.payload.status = 'EMPTY_STATUS_FROM_BACKEND';
        }
        if (index$1._typeof_1(cloneAction.payload.payload) !== 'object') {
          cloneAction.payload.payload = {
            item: {},
            items: []
          };
        }
        if (index$1._typeof_1(cloneAction.payload._meta) !== 'object') {
          cloneAction.payload._meta = {};
        }

        // validate crud actions for status
        if (cloneAction.meta && cloneAction.meta.validStatuses && cloneAction.payload) {
          var _cloneAction$payload = cloneAction.payload,
            payload = _cloneAction$payload === void 0 ? {
              status: 'INTERNAL_ERROR'
            } : _cloneAction$payload,
            _cloneAction$meta = cloneAction.meta,
            _cloneAction$meta$val = _cloneAction$meta.validStatuses,
            validStatuses = _cloneAction$meta$val === void 0 ? [] : _cloneAction$meta$val,
            _cloneAction$meta$err = _cloneAction$meta.errorMessagesByStatus,
            errorMessagesByStatus = _cloneAction$meta$err === void 0 ? {} : _cloneAction$meta$err;
          var status = payload.status;
          if (ignoreStatuses.indexOf(status) < 0 && validStatuses.indexOf(status) < 0) {
            var message = errorMessagesByStatus[status] ? errorMessagesByStatus[status] : 'Something went wrong. Try again later.';
            next({
              type: 'ADD_NOTIFICATION',
              notification: {
                id: parseInt(Math.random().toString().split('.')[1], 10),
                duration: 7000,
                message: message,
                type: 'NOTIFICATION_TYPE_ERROR',
                canDismiss: true
              }
            });
            return Promise.reject(next(action));
          }
        }
        return next(cloneAction);
      }
      return next(action);
    };
  };
});

var RSAA = '@@redux-api-middleware/RSAA';
var listRegexp = /^LIST_(.*)_REQUEST$/;
var crudBeforeMiddleware = (function () {
  var tokenName = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 'dr-pa-token';
  return function (store) {
    return function (next) {
      return function (action) {
        if (action.isCrud) {
          var newAction = index.lodash_clonedeep(action);
          delete newAction.isCrud;

          // stop request for list if is loading
          if (listRegexp.test(action[RSAA].types[0])) {
            var _store$getState = store.getState(),
              isLoading = _store$getState[action.reducer].isLoading;
            if (isLoading) {
              return false;
            }
            delete newAction.reducer;
          }
          if (newAction[RSAA].body && newAction[RSAA].headers['Content-Type'] === 'application/json' && typeof newAction[RSAA].body !== 'string' /* fix */) {
            newAction[RSAA].body = JSON.stringify(newAction[RSAA].body);
          }
          if (action.needToken) {
            newAction[RSAA].headers.Authorization = "Bearer ".concat(utils.getCookie(tokenName));
            delete newAction.needToken;
          }
          return next(newAction);
        }
        return next(action);
      };
    };
  };
});

var initialState = {
  isLoading: {}
};
var crudReducer = (function () {
  var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : initialState;
  var action = arguments.length > 1 ? arguments[1] : undefined;
  var nextState;
  if (action.type.includes('CRUD_ACTION_REQUEST')) {
    var crudName = action.type.split('_')[0];
    nextState = index.lodash_clonedeep(state);
    nextState.isLoading[crudName] = true;
  }
  if (action.type.includes('CRUD_ACTION_SUCCESS') || action.type.includes('CRUD_ACTION_FAILURE')) {
    var _crudName = action.type.split('_')[0];
    nextState = index.lodash_clonedeep(state);
    nextState.isLoading[_crudName] = false;
  }
  return nextState || state;
});

exports.CRUD_ACTION_FAILURE = utils.CRUD_ACTION_FAILURE;
exports.CRUD_ACTION_REQUEST = utils.CRUD_ACTION_REQUEST;
exports.CRUD_ACTION_SUCCESS = utils.CRUD_ACTION_SUCCESS;
exports.crud = utils.crud;
exports.crudAfterMiddleware = crudAfterMiddleware;
exports.crudBeforeMiddleware = crudBeforeMiddleware;
exports.crudReducer = crudReducer;
